/**
 * Scripts for frontend
 */

(function( jQuery ) {
    'use strict';

    jQuery(document).ready(function() {

        var markers = [];
        var geocoder;
        geocoder = new google.maps.Geocoder();

        var infowindow = new google.maps.InfoWindow();

        //Function to center map according to ZIP
        function codeAddress(zipCode) {
            geocoder.geocode( { 'address': zipCode}, function(results, status) {
                if (status == google.maps.GeocoderStatus.OK) {
                    //Got result, center the map and put it out there
                    bf_map.setCenter(results[0].geometry.location);
                } else {
                    alert("We could not find any location with that ZIP code. Let's try again?");
                }
            });
        }


        // Sets the map on all markers in the array.
        function setMapOnAll(map) {
            for (var i = 0; i < markers.length; i++) {
                markers[i].setMap(map);
            }
        }

        // Removes the markers from the map, but keeps them in the array.
        function clearMarkers() {
            setMapOnAll(null);
        }

        // Shows any markers currently in the array.
        function showMarkers() {
            setMapOnAll(map);
        }

        // Deletes all markers in the array by removing references to them.
        function deleteMarkers() {
            clearMarkers();
            markers = [];
        }

        // Update filter content
        function beer_finder_update_content($content) {

            var $xml = jQuery($content);

            // Find Brands
            var $brand = $xml.find("brand");

            $brand.each(function(){

                var name = jQuery(this).text();

                if (jQuery(this).text()!="") {
                    jQuery("#beer_types").append('<option value="'+name+'">' +name+ '</option>');
                }

            });

            // Find Location Types
            var $location = $xml.find("location");
            var inp_id = 0;

            /*$location.each(function(){

                var name = jQuery(this).text();

                if (jQuery(this).text()!="") {
                    inp_id++;
                    jQuery("#location_types").append('<input id="bf_loc_'+inp_id+'" type="checkbox" value="'+name+'" data-code="'+jQuery(this).attr('code')+'" checked>' +name+ '</input><div class="clearfix"></div>');
                }

            });*/

            jQuery("#beer_types").selectOrDie({
                onChange: function(){

                }
            });

            jQuery('#bf_first_hide').removeClass('per_init');
            // Enable pointer events and hide preloader
            $beer_finder_wrapper.removeClass('beer_finder-wait');


        }

        // Update map content
        function beer_finder_update_map($content) {

            var $xml = jQuery($content);

            // Find Brands
            var $brand = $xml.find("location");

            var $this_map=jQuery('#bf_map');

            var $results_content="";
            jQuery('#bf_results_inner').html('');

            $brand.each(function(){

                var name = jQuery(this).text();
                //console.log(name);
                if (jQuery(this).find('lat').text()!==undefined && jQuery(this).find('long').text()!==undefined) {

                    //Add infowindow
                    var $info_content='';
                    //$info_content+='<span class="bfl_distance">'+jQuery(this).find('distance').text()+' miles</span>';
                    $info_content+='<span class="bfl_title">'+jQuery(this).find('dba').text()+'</span>';
                    $info_content+='<span class="bfl_address">'+jQuery(this).find('street').text()+'<br />'+jQuery(this).find('city').text()+','+jQuery(this).find('state').text()+'</span>';
                    $info_content+='<span class="bfl_phone"><a href="tel:'+jQuery(this).find('phone').text()+'">'+jQuery(this).find('phoneFormatted').text()+'</a></span>';

                    var infowindow = new google.maps.InfoWindow({
                        content: $info_content,
                        maxWidth: 230
                    });
                    var marker = new google.maps.Marker({
                        position: new google.maps.LatLng(jQuery(this).find('lat').text(), jQuery(this).find('long').text()),
                        map: bf_map,
                        //icon: $this_map.attr('data-marker'),
                        //size: new google.maps.Size(40,52),
                        //clickable: false,
                        title: jQuery(this).find('dba').text()
                    });
                    marker.addListener('click', function() {
                        jQuery(".gm-style-iw").find('button').click();
                        infowindow.open(bf_map, marker);
                    });
                    markers.push(marker);

                    //Add entry to results list
                    $results_content+='<li>';
                    $results_content+='<span class="bfl_distance">'+jQuery(this).find('distance').text()+' miles</span>';
                    $results_content+='<span class="bfl_title">'+jQuery(this).find('dba').text()+'</span>';
                    $results_content+='<span class="bfl_address">'+jQuery(this).find('street').text()+'<br />'+jQuery(this).find('city').text()+','+jQuery(this).find('state').text()+'</span>';
                    $results_content+='<span class="bfl_phone"><a href="tel:'+jQuery(this).find('phone').text()+'">'+jQuery(this).find('phoneFormatted').text()+'</a></span>';
                    $results_content+='</li>';

                }

            });

            if ($results_content!=="" && !$this_map.hasClass('bf_first_batch')) {
                jQuery('#bf_results_inner').html('<ul>'+$results_content+'</ul>');
                jQuery('#bf_results').slideDown(1000);
            }
            jQuery('#bf_results_inner ul>li').on('click',function(e) {
                jQuery('#bf_results_inner ul>li').removeClass('bf_active');
                jQuery(this).addClass('bf_active');
                google.maps.event.trigger(markers[(jQuery('#bf_results_inner ul>li.bf_active').index())], 'click');
                bf_map.panTo(markers[(jQuery('#bf_results_inner ul>li.bf_active').index())].getPosition());
            });

            $this_map.removeClass('bf_first_batch');

            // Enable pointer events and hide preloader
            $beer_finder_wrapper.removeClass('beer_finder-wait');

        }
        jQuery('#beer_finder_close a').on('click',function(e) {
            e.preventDefault();
            jQuery('#bf_results').slideUp(500);
        });



        // Find wrapper
        var $beer_finder_wrapper=jQuery('.beer_finder-wrap');

        // Get pagination information
        var $perpage=$beer_finder_wrapper.find('.beer_finder-pagination-wrap').attr('data-perpage');

        // Sort click event - ready for Ajax loaded content
        function beer_finder_init() {

            // Disable pointer events and show preloader until Ajax response
            $beer_finder_wrapper.addClass('beer_finder-wait');

            // Reset pagination
            var $new_page=1;

            // Get sort information
            var $sort=jQuery(this).attr('data-orderby');

            // Get order information
            var $order=jQuery(this).attr('data-order');

            // Make ajax request
            jQuery.ajax({
                url: beer_finder_ajax_object.ajaxurl,
                data: {
                    'action': 'beer_finder_do_ajax',
                    'current_zip' : $beer_finder_wrapper.attr('data-zip'),
                    'current_action' : 'brands',
                    'security': beer_finder_ajax_object.ajax_nonce,
                },
                success:function(data) {

                    // Update table content
                    beer_finder_update_content(data);
                    //console.log(data);

                },
                error: function(errorThrown){
                    console.log(errorThrown);
                }
            });
        }

        function beer_finder_results() {

            // Disable pointer events and show preloader until Ajax response
            $beer_finder_wrapper.addClass('beer_finder-wait');
//console.log($beer_finder_wrapper.attr('data-zip'));
            // Make ajax request
            jQuery.ajax({
                url: beer_finder_ajax_object.ajaxurl,
                data: {
                    'action': 'beer_finder_do_ajax',
                    'current_zip' : $beer_finder_wrapper.attr('data-zip'),
                    'current_miles' : $beer_finder_wrapper.attr('data-miles'),
                    'current_brand' : $beer_finder_wrapper.attr('data-brand'),
                    'current_type' : $beer_finder_wrapper.attr('data-type'),
                    'current_action' : 'results',
                    'security': beer_finder_ajax_object.ajax_nonce,
                },
                success:function(data) {

                    // Update table content
                    beer_finder_update_map(data);
                    //console.log(data);

                },
                error: function(errorThrown){
                    console.log(errorThrown);
                }
            });
        }

        if (jQuery('#bf_map').length) {
            beer_finder_init();
            beer_finder_results();
        }

        jQuery('#beer_finder_trigger a').on('click',function(e) {
            e.preventDefault();
            //console.log(jQuery('#bf_zip').attr('value'));

            if (jQuery('#bf_zip').val()!=="") {

                deleteMarkers();
                //console.log(jQuery('#bf_zip').val());
                //Update ZIP
                $beer_finder_wrapper.attr('data-zip', jQuery('#bf_zip').val());

                //Update Brand
                if (jQuery('#beer_types option:selected').attr('value') !== "all") {
                    var remove_spaces = encodeURI(jQuery('#beer_types option:selected').attr('value'));
                    $beer_finder_wrapper.attr('data-brand', remove_spaces);
                } else {
                    $beer_finder_wrapper.attr('data-brand', 'all');
                }

                //Update Miles
                $beer_finder_wrapper.attr('data-miles', jQuery('#location_distance option:selected').attr('value'));

                //Update location type
                var locs_string = "";
                jQuery('#location_types input').each(function () {
                    if (jQuery(this).is(":checked")) {
                        locs_string += jQuery(this).attr('data-code') + ',';
                    }
                });
                //remove last comma
                if (locs_string != "") {
                    locs_string = locs_string.replace(/,\s*$/, "");
                    $beer_finder_wrapper.attr('data-type', locs_string);
                } else {
                    $beer_finder_wrapper.attr('data-type', 'all');
                }
                //console.log(locs_string);

                //Update Map Position
                codeAddress(jQuery('#bf_zip').val());

                beer_finder_results();
            }
            else {
                alert("Please enter a ZIP code.");
            }
        });



    });

    



})( jQuery );